@@ -94,6 +94,7 @@ const char *gdu_device_get_mount_path (GduDevice *device);
 char **gdu_device_get_mount_paths (GduDevice *device);
 uid_t gdu_device_get_mounted_by_uid (GduDevice *device);
 gboolean    gdu_device_get_presentation_hide (GduDevice *device);
+gboolean    gdu_device_get_presentation_nopolicy (GduDevice *device);
 const char *gdu_device_get_presentation_name (GduDevice *device);
 const char *gdu_device_get_presentation_icon_name (GduDevice *device);
 
@@ -138,6 +139,8 @@ const char *gdu_device_drive_get_media (GduDevice *device);
 gboolean gdu_device_drive_get_is_media_ejectable (GduDevice *device);
 gboolean gdu_device_drive_get_requires_eject (GduDevice *device);
 gboolean gdu_device_drive_get_can_detach (GduDevice *device);
+gboolean gdu_device_drive_get_can_spindown (GduDevice *device);
+gboolean gdu_device_drive_get_is_rotational (GduDevice *device);
 
 gboolean gdu_device_optical_disc_get_is_blank (GduDevice *device);
 gboolean gdu_device_optical_disc_get_is_appendable (GduDevice *device);
@@ -168,50 +171,11 @@ const char *gdu_device_linux_md_get_sync_action (GduDevice *device);
 double      gdu_device_linux_md_get_sync_percentage (GduDevice *device);
 guint64     gdu_device_linux_md_get_sync_speed (GduDevice *device);
 
-typedef enum {
-        GDU_ATA_SMART_OFFLINE_DATA_COLLECTION_STATUS_NEVER,
-        GDU_ATA_SMART_OFFLINE_DATA_COLLECTION_STATUS_SUCCESS,
-        GDU_ATA_SMART_OFFLINE_DATA_COLLECTION_STATUS_INPROGRESS,
-        GDU_ATA_SMART_OFFLINE_DATA_COLLECTION_STATUS_SUSPENDED,
-        GDU_ATA_SMART_OFFLINE_DATA_COLLECTION_STATUS_ABORTED,
-        GDU_ATA_SMART_OFFLINE_DATA_COLLECTION_STATUS_FATAL,
-        GDU_ATA_SMART_OFFLINE_DATA_COLLECTION_STATUS_UNKNOWN,
-} GduAtaSmartOfflineDataCollectionStatus;
 
-typedef enum {
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_SUCCESS_OR_NEVER = 0,
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_ABORTED = 1,
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_INTERRUPTED = 2,
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_FATAL = 3,
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_ERROR_UNKNOWN = 4,
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_ERROR_ELECTRICAL = 5,
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_ERROR_SERVO = 6,
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_ERROR_READ = 7,
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_ERROR_HANDLING = 8,
-        GDU_ATA_SMART_SELF_TEST_EXECUTION_STATUS_INPROGRESS = 15,
-} GduAtaSmartSelfTestExecutionStatus;
-
-gboolean    gdu_device_drive_ata_smart_get_is_available (GduDevice *device);
-gboolean    gdu_device_drive_ata_smart_get_is_failing (GduDevice *device);
-gboolean    gdu_device_drive_ata_smart_get_is_failing_valid (GduDevice *device);
-gboolean    gdu_device_drive_ata_smart_get_has_bad_sectors (GduDevice *device);
-gboolean    gdu_device_drive_ata_smart_get_has_bad_attributes (GduDevice *device);
-gdouble     gdu_device_drive_ata_smart_get_temperature_kelvin (GduDevice *device);
-guint64     gdu_device_drive_ata_smart_get_power_on_seconds (GduDevice *device);
-guint64     gdu_device_drive_ata_smart_get_time_collected (GduDevice *device);
-GduAtaSmartOfflineDataCollectionStatus gdu_device_drive_ata_smart_get_offline_data_collection_status (GduDevice *device);
-guint       gdu_device_drive_ata_smart_get_offline_data_collection_seconds (GduDevice *device);
-GduAtaSmartSelfTestExecutionStatus gdu_device_drive_ata_smart_get_self_test_execution_status (GduDevice *device);
-guint       gdu_device_drive_ata_smart_get_self_test_execution_percent_remaining (GduDevice *device);
-gboolean    gdu_device_drive_ata_smart_get_short_and_extended_self_test_available (GduDevice *device);
-gboolean    gdu_device_drive_ata_smart_get_conveyance_self_test_available (GduDevice *device);
-gboolean    gdu_device_drive_ata_smart_get_start_self_test_available (GduDevice *device);
-gboolean    gdu_device_drive_ata_smart_get_abort_self_test_available (GduDevice *device);
-guint       gdu_device_drive_ata_smart_get_short_self_test_polling_minutes (GduDevice *device);
-guint       gdu_device_drive_ata_smart_get_extended_self_test_polling_minutes (GduDevice *device);
-guint       gdu_device_drive_ata_smart_get_conveyance_self_test_polling_minutes (GduDevice *device);
-GList      *gdu_device_drive_ata_smart_get_attributes (GduDevice *device);
-GduAtaSmartAttribute *gdu_device_drive_ata_smart_get_attribute (GduDevice *device, const gchar *attr_name);
+gboolean      gdu_device_drive_ata_smart_get_is_available (GduDevice *device);
+guint64       gdu_device_drive_ata_smart_get_time_collected (GduDevice *device);
+const gchar  *gdu_device_drive_ata_smart_get_status (GduDevice *device);
+gconstpointer gdu_device_drive_ata_smart_get_blob (GduDevice *device, gsize *out_size);
 
 /* ---------------------------------------------------------------------------------------------------- */
 
@@ -355,21 +319,6 @@ void gdu_device_op_cancel_job (GduDevice *device,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-void gdu_device_drive_ata_smart_get_historical_data (GduDevice                                         *device,
-                                                     guint64                                            since,
-                                                     guint64                                            until,
-                                                     guint64                                            spacing,
-                                                     GduDeviceDriveAtaSmartGetHistoricalDataCompletedFunc  callback,
-                                                     gpointer                                           user_data);
-
-GList *gdu_device_drive_ata_smart_get_historical_data_sync (GduDevice  *device,
-                                                            guint64     since,
-                                                            guint64     until,
-                                                            guint64     spacing,
-                                                            GError    **error);
-
-/* ---------------------------------------------------------------------------------------------------- */
-
 void gdu_device_filesystem_list_open_files (GduDevice                                     *device,
                                             GduDeviceFilesystemListOpenFilesCompletedFunc  callback,
                                             gpointer                                       user_data);
