@@ -21,7 +21,7 @@
 
 #include <config.h>
 #include <string.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <dbus/dbus-glib.h>
 
 #include "gdu-presentable.h"
